@@ -292,3 +292,7 @@ class QueryCacheSize(VariableBase):
 class QueryCacheType(VariableBase):
     variable_name="query_cache_type"
     variable_type="str"
+
+class Version(VariableBase):
+    variable_name="version"
+    variable_type="str"
